@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -1364,14 +1364,14 @@ using Mat4f = Mat4d;
 } // namespace math
 
 
-template<> inline math::Mat4s zeroVal<math::Mat4s>() { return math::Mat4s::identity(); }
-template<> inline math::Mat4d zeroVal<math::Mat4d>() { return math::Mat4d::identity(); }
+template<> inline math::Mat4s zeroVal<math::Mat4s>() { return math::Mat4s::zero(); }
+template<> inline math::Mat4d zeroVal<math::Mat4d>() { return math::Mat4d::zero(); }
 
 } // namespace OPENVDB_VERSION_NAME
 } // namespace openvdb
 
 #endif // OPENVDB_UTIL_MAT4_H_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
