@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2016 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -31,11 +31,13 @@
 #ifndef OPENVDB_MATH_VEC4_HAS_BEEN_INCLUDED
 #define OPENVDB_MATH_VEC4_HAS_BEEN_INCLUDED
 
-#include <cmath>
 #include <openvdb/Exceptions.h>
 #include "Math.h"
 #include "Tuple.h"
 #include "Vec3.h"
+#include <algorithm>
+#include <cmath>
+#include <type_traits>
 
 
 namespace openvdb {
@@ -49,13 +51,13 @@ template<typename T>
 class Vec4: public Tuple<4, T>
 {
 public:
-    typedef T value_type;
-    typedef T ValueType;
+    using value_type = T;
+    using ValueType = T;
 
     /// Trivial constructor, the vector is NOT initialized
     Vec4() {}
 
-    /// Constructor with one argument, e.g.   Vec4f v(0);
+    /// @brief Construct a vector all of whose components have the given value.
     explicit Vec4(T val) { this->mm[0] = this->mm[1] = this->mm[2] = this->mm[3] = val; }
 
     /// Constructor with four arguments, e.g.   Vec4f v(1,2,3,4);
@@ -87,6 +89,16 @@ public:
         this->mm[3] = static_cast<T>(v[3]);
     }
 
+    /// @brief Construct a vector all of whose components have the given value,
+    /// which may be of an arithmetic type different from this vector's value type.
+    /// @details Type conversion warnings are suppressed.
+    template<typename Other>
+    explicit Vec4(Other val,
+        typename std::enable_if<std::is_arithmetic<Other>::value, Conversion>::type = Conversion{})
+    {
+        this->mm[0] = this->mm[1] = this->mm[2] = this->mm[3] = static_cast<T>(val);
+    }
+
     /// Reference to the component, e.g.   v.x() = 4.5f;
     T& x() { return this->mm[0]; }
     T& y() { return this->mm[1]; }
@@ -141,7 +153,7 @@ public:
 
     /// Test if "this" vector is equivalent to vector v with tolerance
     /// of eps
-    bool eq(const Vec4<T> &v, T eps=1.0e-8) const
+    bool eq(const Vec4<T> &v, T eps = static_cast<T>(1.0e-8)) const
     {
         return isApproxEqual(this->mm[0], v.mm[0], eps) &&
             isApproxEqual(this->mm[1], v.mm[1], eps) &&
@@ -236,7 +248,7 @@ public:
             + this->mm[2]*this->mm[2] + this->mm[3]*this->mm[3]);
     }
 
-    /// Return a reference to itsef after the exponent has been
+    /// Return a reference to itself after the exponent has been
     /// applied to all the vector components.
     inline const Vec4<T>& exp()
     {
@@ -247,15 +259,31 @@ public:
         return *this;
     }
 
+    /// Return a reference to itself after log has been
+    /// applied to all the vector components.
+    inline const Vec4<T>& log()
+    {
+        this->mm[0] = std::log(this->mm[0]);
+        this->mm[1] = std::log(this->mm[1]);
+        this->mm[2] = std::log(this->mm[2]);
+        this->mm[3] = std::log(this->mm[3]);
+        return *this;
+    }
+
     /// Return the sum of all the vector components.
     inline T sum() const
     {
         return this->mm[0] + this->mm[1] + this->mm[2] + this->mm[3];
     }
 
+    /// Return the product of all the vector components.
+    inline T product() const
+    {
+        return this->mm[0] * this->mm[1] * this->mm[2] * this->mm[3];
+    }
 
     /// this = normalized this
-    bool normalize(T eps=1.0e-8)
+    bool normalize(T eps = static_cast<T>(1.0e-8))
     {
         T d = length();
         if (isApproxEqual(d, T(0), eps)) {
@@ -282,7 +310,14 @@ public:
         return *this / len;
     }
 
-    /// Returns v, where \f$v_i *= scalar\f$ for \f$i \in [0, 3]\f$
+    /// return normalized this, or (1, 0, 0, 0) if this is null vector
+    Vec4<T> unitSafe() const
+    {
+        T l2 = lengthSqr();
+        return l2 ? *this / static_cast<T>(sqrt(l2)) : Vec4<T>(1, 0, 0, 0);
+    }
+
+    /// Multiply each element of this vector by @a scalar.
     template <typename S>
     const Vec4<T> &operator*=(S scalar)
     {
@@ -293,7 +328,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i *= v1_i\f$ for \f$i \in [0, 3]\f$
+    /// Multiply each element of this vector by the corresponding element of the given vector.
     template <typename S>
     const Vec4<T> &operator*=(const Vec4<S> &v1)
     {
@@ -305,7 +340,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i /= scalar\f$ for \f$i \in [0, 3]\f$
+    /// Divide each element of this vector by @a scalar.
     template <typename S>
     const Vec4<T> &operator/=(S scalar)
     {
@@ -316,7 +351,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i /= v1_i\f$ for \f$i \in [0, 3]\f$
+    /// Divide each element of this vector by the corresponding element of the given vector.
     template <typename S>
     const Vec4<T> &operator/=(const Vec4<S> &v1)
     {
@@ -327,7 +362,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i += scalar\f$ for \f$i \in [0, 3]\f$
+    /// Add @a scalar to each element of this vector.
     template <typename S>
     const Vec4<T> &operator+=(S scalar)
     {
@@ -338,7 +373,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i += v1_i\f$ for \f$i \in [0, 3]\f$
+    /// Add each element of the given vector to the corresponding element of this vector.
     template <typename S>
     const Vec4<T> &operator+=(const Vec4<S> &v1)
     {
@@ -349,7 +384,7 @@ public:
         return *this;
     }
 
-    /// Returns v, where \f$v_i += scalar\f$ for \f$i \in [0, 3]\f$
+    /// Subtract @a scalar from each element of this vector.
     template <typename S>
     const Vec4<T> &operator-=(S scalar)
     {
@@ -360,7 +395,7 @@ public:
         return *this;
     }
 
-    /// Returns v0, where \f$v0_i -= v1_i\f$ for \f$i \in [0, 3]\f$
+    /// Subtract each element of the given vector from the corresponding element of this vector.
     template <typename S>
     const Vec4<T> &operator-=(const Vec4<S> &v1)
     {
@@ -376,30 +411,10 @@ public:
     static unsigned numColumns()  { return 4; }
     static unsigned numElements()  { return 4; }
 
-    /// True if a Nan is present in vector
-    bool isNan() const
-    {
-        return isnan(this->mm[0]) || isnan(this->mm[1])
-            || isnan(this->mm[2]) || isnan(this->mm[3]);
-    }
-
-    /// True if an Inf is present in vector
-    bool isInfinite() const
-    {
-        return isinf(this->mm[0]) || isinf(this->mm[1])
-            || isinf(this->mm[2]) || isinf(this->mm[3]);
-    }
-
-    /// True if all no Nan or Inf values present
-    bool isFinite() const
-    {
-        return finite(this->mm[0]) && finite(this->mm[1])
-            && finite(this->mm[2]) && finite(this->mm[3]);
-    }
-
     /// Predefined constants, e.g.   Vec4f v = Vec4f::xNegAxis();
     static Vec4<T> zero() { return Vec4<T>(0, 0, 0, 0); }
     static Vec4<T> origin() { return Vec4<T>(0, 0, 0, 1); }
+    static Vec4<T> ones() { return Vec4<T>(1, 1, 1, 1); }
 };
 
 /// Equality operator, does exact floating point comparisons
@@ -417,12 +432,12 @@ inline bool operator==(const Vec4<T0> &v0, const Vec4<T1> &v1)
 template <typename T0, typename T1>
 inline bool operator!=(const Vec4<T0> &v0, const Vec4<T1> &v1) { return !(v0==v1); }
 
-/// Returns V, where \f$V_i = v_i * scalar\f$ for \f$i \in [0, 3]\f$
+/// Multiply each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec4<typename promote<S, T>::type> operator*(S scalar, const Vec4<T> &v)
 { return v*scalar; }
 
-/// Returns V, where \f$V_i = v_i * scalar\f$ for \f$i \in [0, 3]\f$
+/// Multiply each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec4<typename promote<S, T>::type> operator*(const Vec4<T> &v, S scalar)
 {
@@ -431,10 +446,9 @@ inline Vec4<typename promote<S, T>::type> operator*(const Vec4<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i * v1_i\f$ for \f$i \in [0, 3]\f$
+/// Multiply corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
-inline Vec4<typename promote<T0, T1>::type> operator*(const Vec4<T0> &v0,
-                                               const Vec4<T1> &v1)
+inline Vec4<typename promote<T0, T1>::type> operator*(const Vec4<T0> &v0, const Vec4<T1> &v1)
 {
     Vec4<typename promote<T0, T1>::type> result(v0[0]*v1[0],
                                                 v0[1]*v1[1],
@@ -443,7 +457,7 @@ inline Vec4<typename promote<T0, T1>::type> operator*(const Vec4<T0> &v0,
     return result;
 }
 
-/// Returns V, where \f$V_i = scalar / v_i\f$ for \f$i \in [0, 3]\f$
+/// Divide @a scalar by each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec4<typename promote<S, T>::type> operator/(S scalar, const Vec4<T> &v)
 {
@@ -453,7 +467,7 @@ inline Vec4<typename promote<S, T>::type> operator/(S scalar, const Vec4<T> &v)
                                               scalar/v[3]);
 }
 
-/// Returns V, where \f$V_i = v_i / scalar\f$ for \f$i \in [0, 3]\f$
+/// Divide each element of the given vector by @a scalar and return the result.
 template <typename S, typename T>
 inline Vec4<typename promote<S, T>::type> operator/(const Vec4<T> &v, S scalar)
 {
@@ -462,17 +476,16 @@ inline Vec4<typename promote<S, T>::type> operator/(const Vec4<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i / v1_i\f$ for \f$i \in [0, 3]\f$
+/// Divide corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
-inline Vec4<typename promote<T0, T1>::type> operator/(const Vec4<T0> &v0,
-                                               const Vec4<T1> &v1)
+inline Vec4<typename promote<T0, T1>::type> operator/(const Vec4<T0> &v0, const Vec4<T1> &v1)
 {
     Vec4<typename promote<T0, T1>::type>
         result(v0[0]/v1[0], v0[1]/v1[1], v0[2]/v1[2], v0[3]/v1[3]);
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i + v1_i\f$ for \f$i \in [0, 3]\f$
+/// Add corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec4<typename promote<T0, T1>::type> operator+(const Vec4<T0> &v0, const Vec4<T1> &v1)
 {
@@ -481,7 +494,7 @@ inline Vec4<typename promote<T0, T1>::type> operator+(const Vec4<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v_i + scalar\f$ for \f$i \in [0, 3]\f$
+/// Add @a scalar to each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec4<typename promote<S, T>::type> operator+(const Vec4<T> &v, S scalar)
 {
@@ -490,7 +503,7 @@ inline Vec4<typename promote<S, T>::type> operator+(const Vec4<T> &v, S scalar)
     return result;
 }
 
-/// Returns V, where \f$V_i = v0_i - v1_i\f$ for \f$i \in [0, 3]\f$
+/// Subtract corresponding elements of @a v0 and @a v1 and return the result.
 template <typename T0, typename T1>
 inline Vec4<typename promote<T0, T1>::type> operator-(const Vec4<T0> &v0, const Vec4<T1> &v1)
 {
@@ -499,7 +512,7 @@ inline Vec4<typename promote<T0, T1>::type> operator-(const Vec4<T0> &v0, const
     return result;
 }
 
-/// Returns V, where \f$V_i = v_i - scalar\f$ for \f$i \in [0, 3]\f$
+/// Subtract @a scalar from each element of the given vector and return the result.
 template <typename S, typename T>
 inline Vec4<typename promote<S, T>::type> operator-(const Vec4<T> &v, S scalar)
 {
@@ -524,21 +537,6 @@ isApproxEqual(const Vec4<T>& a, const Vec4<T>& b, const Vec4<T>& eps)
            isApproxEqual(a[3], b[3], eps[3]);
 }
 
-template<typename T>
-inline bool
-isFinite(const Vec4<T>& v)
-{
-    return isFinite(v[0]) && isFinite(v[1]) && isFinite(v[2]) && isFinite(v[3]);
-}
-
-/// Return @c true if all components are exactly equal to zero.
-template<typename T>
-inline bool
-isZero(const Vec4<T>& v)
-{
-    return isZero(v[0]) && isZero(v[1]) && isZero(v[2]) && isZero(v[3]);
-}
-
 template<typename T>
 inline Vec4<T>
 Abs(const Vec4<T>& v)
@@ -578,10 +576,15 @@ inline Vec4<T> maxComponent(const Vec4<T> &v1, const Vec4<T> &v2)
 template <typename T>
 inline Vec4<T> Exp(Vec4<T> v) { return v.exp(); }
 
-typedef Vec4<int32_t>   Vec4i;
-typedef Vec4<uint32_t>  Vec4ui;
-typedef Vec4<float>     Vec4s;
-typedef Vec4<double>    Vec4d;
+/// @brief Return a vector with log applied to each of
+/// the components of the input vector.
+template <typename T>
+inline Vec4<T> Log(Vec4<T> v) { return v.log(); }
+
+using Vec4i = Vec4<int32_t>;
+using Vec4ui = Vec4<uint32_t>;
+using Vec4s = Vec4<float>;
+using Vec4d = Vec4<double>;
 
 } // namespace math
 } // namespace OPENVDB_VERSION_NAME
@@ -589,6 +592,6 @@ typedef Vec4<double>    Vec4d;
 
 #endif // OPENVDB_MATH_VEC4_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2016 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
