@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -671,6 +671,8 @@ public:
 
     ValueType get(Index n, Index m = 0) const;
 
+    const AttributeArray& array() const;
+
 protected:
     Index index(Index n, Index m) const;
 
@@ -741,6 +743,8 @@ public:
     void set(Index n, const ValueType& value);
     void set(Index n, Index m, const ValueType& value);
 
+    AttributeArray& array();
+
 private:
     friend class ::TestAttributeArray;
 
@@ -908,7 +912,7 @@ TypedAttributeArray<ValueType_, Codec_>::TypedAttributeArray(const TypedAttribut
 
 
 template<typename ValueType_, typename Codec_>
-typename TypedAttributeArray<ValueType_, Codec_>::TypedAttributeArray&
+TypedAttributeArray<ValueType_, Codec_>&
 TypedAttributeArray<ValueType_, Codec_>::operator=(const TypedAttributeArray& rhs)
 {
     if (&rhs != this) {
@@ -1933,6 +1937,13 @@ AttributeHandle<ValueType, CodecType>::compatibleType() const
     return mArray->isType<TypedAttributeArray<ValueType, CodecType>>();
 }
 
+template <typename ValueType, typename CodecType>
+const AttributeArray& AttributeHandle<ValueType, CodecType>::array() const
+{
+    assert(mArray);
+    return *mArray;
+}
+
 template <typename ValueType, typename CodecType>
 Index AttributeHandle<ValueType, CodecType>::index(Index n, Index m) const
 {
@@ -2060,6 +2071,13 @@ AttributeWriteHandle<ValueType, CodecType>::set(Index index, const ValueType& va
     TypedAttributeArray<ValueType, CodecType>::setUnsafe(const_cast<AttributeArray*>(this->mArray), index, value);
 }
 
+template <typename ValueType, typename CodecType>
+AttributeArray& AttributeWriteHandle<ValueType, CodecType>::array()
+{
+    assert(this->mArray);
+    return *const_cast<AttributeArray*>(this->mArray);
+}
+
 
 } // namespace points
 } // namespace OPENVDB_VERSION_NAME
@@ -2067,6 +2085,6 @@ AttributeWriteHandle<ValueType, CodecType>::set(Index index, const ValueType& va
 
 #endif // OPENVDB_POINTS_ATTRIBUTE_ARRAY_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
