@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -249,10 +249,12 @@ setStreamingMode(PointDataTreeT& tree, bool on = true);
 /// @brief  Sequentially pre-fetch all delayed-load voxel and attribute data from disk in order
 ///         to accelerate subsequent random access.
 ///
-/// @param  tree the PointDataTree.
+/// @param  tree                the PointDataTree.
+/// @param  position            if enabled, prefetch the position attribute (default is on)
+/// @param  otherAttributes     if enabled, prefetch all other attributes (default is on)
 template <typename PointDataTreeT>
 inline void
-prefetch(PointDataTreeT& tree);
+prefetch(PointDataTreeT& tree, bool position = true, bool otherAttributes = true);
 
 
 ////////////////////////////////////////
@@ -633,7 +635,7 @@ public:
 
 public:
 
-#ifdef _MSC_VER
+#if defined(_MSC_VER) && (_MSC_VER < 1914)
     using ValueOnIter = typename BaseLeaf::ValueIter<
         MaskOnIterator, PointDataLeafNode, const ValueType, ValueOn>;
     using ValueOnCIter = typename BaseLeaf::ValueIter<
@@ -691,20 +693,41 @@ public:
     using IndexOffIter      = IndexIter<ValueOffCIter, NullFilter>;
 
     /// @brief Leaf index iterator
-    IndexAllIter beginIndexAll() const;
-    IndexOnIter beginIndexOn() const;
-    IndexOffIter beginIndexOff() const;
+    IndexAllIter beginIndexAll() const
+    {
+	NullFilter filter;
+	return this->beginIndex<ValueAllCIter, NullFilter>(filter);
+    }
+    IndexOnIter beginIndexOn() const
+    {
+	NullFilter filter;
+	return this->beginIndex<ValueOnCIter, NullFilter>(filter);
+    }
+    IndexOffIter beginIndexOff() const
+    {
+	NullFilter filter;
+	return this->beginIndex<ValueOffCIter, NullFilter>(filter);
+    }
 
     template<typename IterT, typename FilterT>
     IndexIter<IterT, FilterT> beginIndex(const FilterT& filter) const;
 
     /// @brief Filtered leaf index iterator
     template<typename FilterT>
-    IndexIter<ValueAllCIter, FilterT> beginIndexAll(const FilterT& filter) const;
+    IndexIter<ValueAllCIter, FilterT> beginIndexAll(const FilterT& filter) const
+    {
+	return this->beginIndex<ValueAllCIter, FilterT>(filter);
+    }
     template<typename FilterT>
-    IndexIter<ValueOnCIter, FilterT> beginIndexOn(const FilterT& filter) const;
+    IndexIter<ValueOnCIter, FilterT> beginIndexOn(const FilterT& filter) const
+    {
+	return this->beginIndex<ValueOnCIter, FilterT>(filter);
+    }
     template<typename FilterT>
-    IndexIter<ValueOffCIter, FilterT> beginIndexOff(const FilterT& filter) const;
+    IndexIter<ValueOffCIter, FilterT> beginIndexOff(const FilterT& filter) const
+    {
+	return this->beginIndex<ValueOffCIter, FilterT>(filter);
+    }
 
     /// @brief Leaf index iterator from voxel
     IndexVoxelIter beginIndexVoxel(const Coord& ijk) const;
@@ -782,9 +805,7 @@ PointDataLeafNode<T, Log2Dim>::clearAttributes(const bool updateValueMask)
 
     // zero voxel values
 
-    for (Index n = 0; n < LeafNodeType::NUM_VALUES; n++) {
-        this->setOffsetOnly(n, 0);
-    }
+    this->buffer().fill(ValueType(0));
 
     // if updateValueMask, also de-activate all voxels
 
@@ -1001,65 +1022,26 @@ template<typename ValueIterT, typename FilterT>
 inline IndexIter<ValueIterT, FilterT>
 PointDataLeafNode<T, Log2Dim>::beginIndex(const FilterT& filter) const
 {
+    // generate no-op iterator if filter evaluates no indices
+
+    if (filter.state() == index::NONE) {
+        return IndexIter<ValueIterT, FilterT>(ValueIterT(), filter);
+    }
+
+    // copy filter to ensure thread-safety
+
+    FilterT newFilter(filter);
+    newFilter.reset(*this);
+
     using IterTraitsT = tree::IterTraits<LeafNodeType, ValueIterT>;
 
     // construct the value iterator and reset the filter to use this leaf
 
     ValueIterT valueIter = IterTraitsT::begin(*this);
-    FilterT newFilter(filter);
-    newFilter.reset(*this);
 
     return IndexIter<ValueIterT, FilterT>(valueIter, newFilter);
 }
 
-template<typename T, Index Log2Dim>
-template<typename FilterT>
-inline IndexIter<typename PointDataLeafNode<T, Log2Dim>::ValueAllCIter, FilterT>
-PointDataLeafNode<T, Log2Dim>::beginIndexAll(const FilterT& filter) const
-{
-    return this->beginIndex<ValueAllCIter, FilterT>(filter);
-}
-
-template<typename T, Index Log2Dim>
-template<typename FilterT>
-inline IndexIter<typename PointDataLeafNode<T, Log2Dim>::ValueOnCIter, FilterT>
-PointDataLeafNode<T, Log2Dim>::beginIndexOn(const FilterT& filter) const
-{
-    return this->beginIndex<ValueOnCIter, FilterT>(filter);
-}
-
-template<typename T, Index Log2Dim>
-template<typename FilterT>
-inline IndexIter<typename PointDataLeafNode<T, Log2Dim>::ValueOffCIter, FilterT>
-PointDataLeafNode<T, Log2Dim>::beginIndexOff(const FilterT& filter) const
-{
-    return this->beginIndex<ValueOffCIter, FilterT>(filter);
-}
-
-template<typename T, Index Log2Dim>
-inline IndexIter<typename PointDataLeafNode<T, Log2Dim>::ValueAllCIter, NullFilter>
-PointDataLeafNode<T, Log2Dim>::beginIndexAll() const
-{
-    NullFilter filter;
-    return this->beginIndex<ValueAllCIter, NullFilter>(filter);
-}
-
-template<typename T, Index Log2Dim>
-inline typename PointDataLeafNode<T, Log2Dim>::IndexOnIter
-PointDataLeafNode<T, Log2Dim>::beginIndexOn() const
-{
-    NullFilter filter;
-    return this->beginIndex<ValueOnCIter, NullFilter>(filter);
-}
-
-template<typename T, Index Log2Dim>
-inline typename PointDataLeafNode<T, Log2Dim>::IndexOffIter
-PointDataLeafNode<T, Log2Dim>::beginIndexOff() const
-{
-    NullFilter filter;
-    return this->beginIndex<ValueOffCIter, NullFilter>(filter);
-}
-
 template<typename T, Index Log2Dim>
 inline ValueVoxelCIter
 PointDataLeafNode<T, Log2Dim>::beginValueVoxel(const Coord& ijk) const
@@ -1094,7 +1076,7 @@ template<typename T, Index Log2Dim>
 inline Index64
 PointDataLeafNode<T, Log2Dim>::pointCount() const
 {
-    return iterCount(this->beginIndexAll());
+    return this->getLastValue();
 }
 
 template<typename T, Index Log2Dim>
@@ -1123,7 +1105,11 @@ PointDataLeafNode<T, Log2Dim>::groupPointCount(const Name& groupName) const
         return Index64(0);
     }
     GroupFilter filter(groupName, this->attributeSet());
-    return iterCount(this->beginIndexAll(filter));
+    if (filter.state() == index::ALL) {
+        return this->pointCount();
+    } else {
+        return iterCount(this->beginIndexAll(filter));
+    }
 }
 
 template<typename T, Index Log2Dim>
@@ -1645,26 +1631,42 @@ setStreamingMode(PointDataTreeT& tree, bool on)
 
 template <typename PointDataTreeT>
 inline void
-prefetch(PointDataTreeT& tree)
+prefetch(PointDataTreeT& tree, bool position, bool otherAttributes)
 {
-    // sequential pre-fetch of out-of-core data for faster performance
+    // NOTE: the following is intentionally not multi-threaded, as the I/O
+    // is faster if done in the order in which it is stored in the file
 
-    PointDataTree::LeafCIter leafIter = tree.cbeginLeaf();
-    if (leafIter) {
-        const size_t attributes = leafIter->attributeSet().size();
-        // load voxel buffer data
-        for ( ; leafIter; ++leafIter) {
-            const PointDataTree::LeafNodeType::Buffer& buffer = leafIter->buffer();
-            buffer.data();
+    auto leaf = tree.cbeginLeaf();
+    if (!leaf)  return;
+
+    const auto& attributeSet = leaf->attributeSet();
+
+    // pre-fetch leaf data
+
+    for ( ; leaf; ++leaf) {
+        leaf->buffer().data();
+    }
+
+    // pre-fetch position attribute data (position will typically have index 0)
+
+    size_t positionIndex = attributeSet.find("P");
+
+    if (position && positionIndex != AttributeSet::INVALID_POS) {
+        for (leaf = tree.cbeginLeaf(); leaf; ++leaf) {
+            assert(leaf->hasAttribute(positionIndex));
+            leaf->constAttributeArray(positionIndex).loadData();
         }
-        // load attribute data
-        for (size_t pos = 0; pos < attributes; pos++) {
-            leafIter = tree.cbeginLeaf();
-            for ( ; leafIter; ++leafIter) {
-                if (leafIter->hasAttribute(pos)) {
-                    const AttributeArray& array = leafIter->constAttributeArray(pos);
-                    array.loadData();
-                }
+    }
+
+    // pre-fetch other attribute data
+
+    if (otherAttributes) {
+        const size_t attributes = attributeSet.size();
+        for (size_t attributeIndex = 0; attributeIndex < attributes; attributeIndex++) {
+            if (attributeIndex == positionIndex)     continue;
+            for (leaf = tree.cbeginLeaf(); leaf; ++leaf) {
+                assert(leaf->hasAttribute(attributeIndex));
+                leaf->constAttributeArray(attributeIndex).loadData();
             }
         }
     }
@@ -1750,6 +1752,6 @@ struct SameLeafConfig<Dim1, points::PointDataLeafNode<T2, Dim1>> { static const
 
 #endif // OPENVDB_POINTS_POINT_DATA_GRID_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
