@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -43,12 +43,21 @@
 
 #include <openvdb/Types.h>
 #include <openvdb/Grid.h>
-#include <boost/scoped_array.hpp>
+#include <boost/mpl/at.hpp>
+#include <boost/mpl/int.hpp>
 #include <tbb/blocked_range.h>
 #include <tbb/parallel_for.h>
 #include <tbb/parallel_reduce.h>
 #include <tbb/parallel_sort.h>
+#include <algorithm>
+#include <cmath>
+#include <cstdlib>
+#include <deque>
 #include <limits>
+#include <memory>
+#include <set>
+#include <vector>
+
 
 namespace openvdb {
 OPENVDB_USE_VERSION_NAMESPACE
@@ -544,7 +553,7 @@ struct FillMaskBoundary {
         tree::ValueAccessor<const BoolTreeType> maskAcc(*mFillMask);
         tree::ValueAccessor<const TreeType> distAcc(*mTree);
 
-        boost::scoped_array<char> valueMask(new char[BoolLeafNodeType::SIZE]);
+        std::unique_ptr<char[]> valueMask(new char[BoolLeafNodeType::SIZE]);
 
         for (size_t n = range.begin(), N = range.end(); n < N; ++n) {
 
@@ -1010,7 +1019,7 @@ computeEnclosedRegionMask(const TreeType& tree, typename TreeType::ValueType iso
     }
 
     // create mask leafnodes
-    boost::scoped_array<CharLeafNodeType*> maskNodes(new CharLeafNodeType*[numLeafNodes]);
+    std::unique_ptr<CharLeafNodeType*[]> maskNodes(new CharLeafNodeType*[numLeafNodes]);
 
     tbb::parallel_for(tbb::blocked_range<size_t>(0, numLeafNodes),
         LabelBoundaryVoxels<LeafNodeType>(isovalue, &nodes[0], maskNodes.get()));
@@ -1030,7 +1039,7 @@ computeEnclosedRegionMask(const TreeType& tree, typename TreeType::ValueType iso
         std::vector<const BoolLeafNodeType*> fillMaskNodes;
         fillMask->getNodes(fillMaskNodes);
 
-        boost::scoped_array<BoolLeafNodeType*> boundaryMaskNodes(
+        std::unique_ptr<BoolLeafNodeType*[]> boundaryMaskNodes(
             new BoolLeafNodeType*[fillMaskNodes.size()]);
 
         tbb::parallel_for(tbb::blocked_range<size_t>(0, fillMaskNodes.size()),
@@ -1138,7 +1147,7 @@ computeInteriorMask(const TreeType& tree, typename TreeType::ValueType iso)
     }
 
     // create mask leafnodes
-    boost::scoped_array<BoolLeafNodeType*> maskNodes(new BoolLeafNodeType*[numLeafNodes]);
+    std::unique_ptr<BoolLeafNodeType*[]> maskNodes(new BoolLeafNodeType*[numLeafNodes]);
 
     tbb::parallel_for(tbb::blocked_range<size_t>(0, numLeafNodes),
         MaskInteriorVoxels<LeafNodeType>(iso, &nodes[0], maskNodes.get()));
@@ -2383,7 +2392,7 @@ extractActiveVoxelSegmentMasks(const GridOrTreeType& volume,
     // 1. Split node masks into disjoint segments
     // Note: The LeafNode origin coord is modified to record the 'leafnodes' array offset.
 
-    boost::scoped_array<NodeMaskSegmentPtrVector> nodeSegmentArray(
+    std::unique_ptr<NodeMaskSegmentPtrVector[]> nodeSegmentArray(
         new NodeMaskSegmentPtrVector[leafnodes.size()]);
 
     tbb::parallel_for(tbb::blocked_range<size_t>(0, leafnodes.size()),
@@ -2480,8 +2489,8 @@ extractActiveVoxelSegmentMasks(const GridOrTreeType& volume,
     if (masks.size() > 1) {
         const size_t segmentCount = masks.size();
 
-        boost::scoped_array<size_t> segmentOrderArray(new size_t[segmentCount]);
-        boost::scoped_array<size_t> voxelCountArray(new size_t[segmentCount]);
+        std::unique_ptr<size_t[]> segmentOrderArray(new size_t[segmentCount]);
+        std::unique_ptr<size_t[]> voxelCountArray(new size_t[segmentCount]);
 
         for (size_t n = 0; n < segmentCount; ++n) {
             segmentOrderArray[n] = n;
@@ -2611,6 +2620,6 @@ segmentSDF(const GridOrTreeType& volume, std::vector<typename GridOrTreeType::Pt
 
 #endif // OPENVDB_TOOLS_LEVEL_SET_UTIL_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
