@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -51,10 +51,12 @@
 #include <openvdb/math/Math.h>
 #include <openvdb/tools/RayIntersector.h>
 #include <openvdb/tools/Interpolation.h>
-#include <boost/scoped_array.hpp>
 #include <deque>
+#include <iostream>
 #include <fstream>
+#include <limits>
 #include <memory>
+#include <string>
 #include <type_traits>
 #include <vector>
 
@@ -333,7 +335,7 @@ public:
         std::string name(fileName);
         if (name.find_last_of(".") == std::string::npos) name.append(".ppm");
 
-        boost::scoped_array<unsigned char> buffer(new unsigned char[3*mSize]);
+        std::unique_ptr<unsigned char[]> buffer(new unsigned char[3*mSize]);
         unsigned char *tmp = buffer.get(), *q = tmp;
         RGBA* p = mPixels.get();
         size_t n = mSize;
@@ -392,7 +394,7 @@ public:
 
 private:
     size_t mWidth, mHeight, mSize;
-    boost::scoped_array<RGBA> mPixels;
+    std::unique_ptr<RGBA[]> mPixels;
 };// Film
 
 
@@ -1118,6 +1120,6 @@ operator()(const tbb::blocked_range<size_t>& range) const
 
 #endif // OPENVDB_TOOLS_RAYTRACER_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
