@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -36,18 +36,26 @@
 #define OPENVDB_TOOLS_VOLUME_TO_SPHERES_HAS_BEEN_INCLUDED
 
 #include <openvdb/tree/LeafManager.h>
+#include <openvdb/math/Math.h>
 #include "Morphology.h" // for erodeVoxels()
 #include "PointScatter.h"
+#include "LevelSetRebuild.h"
 #include "LevelSetUtil.h"
 #include "VolumeToMesh.h"
 
+#include <boost/mpl/at.hpp>
+#include <boost/mpl/int.hpp>
 #include <boost/scoped_array.hpp>
 #include <tbb/blocked_range.h>
 #include <tbb/parallel_for.h>
 #include <tbb/parallel_reduce.h>
 
-#include <limits> // std::numeric_limits
+#include <algorithm> // for std::min(), std::max()
+#include <cmath> // for std::sqrt()
+#include <limits> // for std::numeric_limits
 #include <memory>
+#include <random>
+#include <utility> // for std::pair
 #include <vector>
 
 
@@ -63,9 +71,10 @@ namespace tools {
 ///                         The first three components of each tuple specify the sphere center,
 ///                         and the fourth specifies the radius.
 ///                         The spheres are ordered by radius, from largest to smallest.
-/// @param maxSphereCount   no more than this number of spheres are generated
+/// @param sphereCount      lower and upper bounds on the number of spheres to be generated<BR>
+///                         The actual number will be somewhere within the bounds.
 /// @param overlapping      toggle to allow spheres to overlap/intersect
-/// @param minRadius        the smallest allowable sphere size, in voxel units
+/// @param minRadius        the smallest allowable sphere size, in voxel units<BR>
 /// @param maxRadius        the largest allowable sphere size, in voxel units
 /// @param isovalue         the voxel value that determines the surface of the volume<BR>
 ///                         The default value of zero works for signed distance fields,
@@ -75,8 +84,26 @@ namespace tools {
 ///                         Increasing this count increases the chances of finding optimal
 ///                         sphere sizes.
 /// @param interrupter      pointer to an object adhering to the util::NullInterrupter interface
+///
+/// @note The minimum sphere count takes precedence over the minimum radius.
 template<typename GridT, typename InterrupterT = util::NullInterrupter>
 inline void
+fillWithSpheres(
+    const GridT& grid,
+    std::vector<openvdb::Vec4s>& spheres,
+    const Vec2i& sphereCount = Vec2i(1, 50),
+    bool overlapping = false,
+    float minRadius = 1.0,
+    float maxRadius = std::numeric_limits<float>::max(),
+    float isovalue = 0.0,
+    int instanceCount = 10000,
+    InterrupterT* interrupter = nullptr);
+
+
+/// @deprecated Use the @a sphereCount overload instead.
+template<typename GridT, typename InterrupterT = util::NullInterrupter>
+OPENVDB_DEPRECATED
+inline void
 fillWithSpheres(
     const GridT& grid,
     std::vector<openvdb::Vec4s>& spheres,
@@ -656,16 +683,81 @@ fillWithSpheres(
     float isovalue,
     int instanceCount,
     InterrupterT* interrupter)
+{
+    fillWithSpheres(grid, spheres, Vec2i(1, maxSphereCount), overlapping,
+        minRadius, maxRadius, isovalue, instanceCount, interrupter);
+}
+
+
+template<typename GridT, typename InterrupterT>
+inline void
+fillWithSpheres(
+    const GridT& grid,
+    std::vector<openvdb::Vec4s>& spheres,
+    const Vec2i& sphereCount,
+    bool overlapping,
+    float minRadius,
+    float maxRadius,
+    float isovalue,
+    int instanceCount,
+    InterrupterT* interrupter)
 {
     spheres.clear();
+
+    if (grid.empty()) return;
+
+    const int
+        minSphereCount = sphereCount[0],
+        maxSphereCount = sphereCount[1];
+    if ((minSphereCount > maxSphereCount) || (maxSphereCount < 1)) {
+        OPENVDB_LOG_WARN("fillWithSpheres: minimum sphere count ("
+            << minSphereCount << ") exceeds maximum count (" << maxSphereCount << ")");
+        return;
+    }
     spheres.reserve(maxSphereCount);
 
-    const bool addNBPoints = grid.activeVoxelCount() < 10000;
+    auto gridPtr = grid.copy(); // shallow copy
+
+    if (gridPtr->getGridClass() == GRID_LEVEL_SET) {
+        // Clamp the isovalue to the level set's background value minus epsilon.
+        // (In a valid narrow-band level set, all voxels, including background voxels,
+        // have values less than or equal to the background value, so an isovalue
+        // greater than or equal to the background value would produce a mask with
+        // effectively infinite extent.)
+        isovalue = std::min(isovalue,
+            static_cast<float>(gridPtr->background() - math::Tolerance<float>::value()));
+    } else if (gridPtr->getGridClass() == GRID_FOG_VOLUME) {
+        // Clamp the isovalue of a fog volume between epsilon and one,
+        // again to avoid a mask with infinite extent.  (Recall that
+        // fog volume voxel values vary from zero outside to one inside.)
+        isovalue = math::Clamp(isovalue, math::Tolerance<float>::value(), 1.f);
+    }
+
+    // ClosestSurfacePoint is inaccurate for small grids.
+    // Resample the input grid if it is too small.
+    auto numVoxels = gridPtr->activeVoxelCount();
+    if (numVoxels < 10000) {
+        const auto scale = 1.0 / math::Cbrt(2.0 * 10000.0 / double(numVoxels));
+        auto scaledXform = gridPtr->transform().copy();
+        scaledXform->preScale(scale);
+
+        auto newGridPtr = levelSetRebuild(*gridPtr, isovalue,
+            LEVEL_SET_HALF_WIDTH, LEVEL_SET_HALF_WIDTH, scaledXform.get(), interrupter);
+
+        const auto newNumVoxels = newGridPtr->activeVoxelCount();
+        if (newNumVoxels > numVoxels) {
+            OPENVDB_LOG_DEBUG_RUNTIME("fillWithSpheres: resampled input grid from "
+                << numVoxels << " voxel" << (numVoxels == 1 ? "" : "s")
+                << " to " << newNumVoxels << " voxel" << (newNumVoxels == 1 ? "" : "s"));
+            gridPtr = newGridPtr;
+            numVoxels = newNumVoxels;
+        }
+    }
+
+    const bool addNarrowBandPoints = (numVoxels < 10000);
     int instances = std::max(instanceCount, maxSphereCount);
 
     using TreeT = typename GridT::TreeType;
-    using ValueT = typename GridT::ValueType;
-
     using BoolTreeT = typename TreeT::template ValueConverter<bool>::Type;
     using Int16TreeT = typename TreeT::template ValueConverter<Int16>::Type;
 
@@ -673,29 +765,16 @@ fillWithSpheres(
         0xccab8ee7, 11, 0xffffffff, 7, 0x31b6ab00, 15, 0xffe50000, 17, 1812433253>; // mt11213b
     RandGen mtRand(/*seed=*/0);
 
-    const TreeT& tree = grid.tree();
-    const math::Transform& transform = grid.transform();
+    const TreeT& tree = gridPtr->tree();
+    math::Transform transform = gridPtr->transform();
 
     std::vector<Vec3R> instancePoints;
     {
         // Compute a mask of the voxels enclosed by the isosurface.
         typename Grid<BoolTreeT>::Ptr interiorMaskPtr;
-        if (grid.getGridClass() == GRID_LEVEL_SET) {
-            // Clamp the isovalue to the level set's background value minus epsilon.
-            // (In a valid narrow-band level set, all voxels, including background voxels,
-            // have values less than or equal to the background value, so an isovalue
-            // greater than or equal to the background value would produce a mask with
-            // effectively infinite extent.)
-            isovalue = std::min(isovalue,
-                static_cast<float>(tree.background() - math::Tolerance<ValueT>::value()));
-            interiorMaskPtr = sdfInteriorMask(grid, ValueT(isovalue));
+        if (gridPtr->getGridClass() == GRID_LEVEL_SET) {
+            interiorMaskPtr = sdfInteriorMask(*gridPtr, isovalue);
         } else {
-            if (grid.getGridClass() == GRID_FOG_VOLUME) {
-                // Clamp the isovalue of a fog volume between epsilon and one,
-                // again to avoid a mask with infinite extent.  (Recall that
-                // fog volume voxel values vary from zero outside to one inside.)
-                isovalue = math::Clamp(isovalue, math::Tolerance<float>::value(), 1.f);
-            }
             // For non-level-set grids, the interior mask comprises the active voxels.
             interiorMaskPtr = typename Grid<BoolTreeT>::Ptr(Grid<BoolTreeT>::create(false));
             interiorMaskPtr->setTransform(transform.copy());
@@ -704,21 +783,32 @@ fillWithSpheres(
 
         if (interrupter && interrupter->wasInterrupted()) return;
 
-        erodeVoxels(interiorMaskPtr->tree(), 1);
+        // If the interior mask is small and eroding it results in an empty grid,
+        // use the uneroded mask instead.  (But if the minimum sphere count is zero,
+        // then eroding away the mask is acceptable.)
+        if (!addNarrowBandPoints || (minSphereCount <= 0)) {
+            erodeVoxels(interiorMaskPtr->tree(), 1);
+        } else {
+            auto& maskTree = interiorMaskPtr->tree();
+            auto copyOfTree = StaticPtrCast<BoolTreeT>(maskTree.copy());
+            erodeVoxels(maskTree, 1);
+            if (maskTree.empty()) { interiorMaskPtr->setTree(copyOfTree); }
+        }
 
         // Scatter candidate sphere centroids (instancePoints)
         instancePoints.reserve(instances);
         v2s_internal::PointAccessor ptnAcc(instancePoints);
 
-        UniformPointScatter<v2s_internal::PointAccessor, RandGen, InterrupterT> scatter(
-            ptnAcc, Index64(addNBPoints ? (instances / 2) : instances), mtRand, 1.0, interrupter);
+        const auto scatterCount = Index64(addNarrowBandPoints ? (instances / 2) : instances);
 
+        UniformPointScatter<v2s_internal::PointAccessor, RandGen, InterrupterT> scatter(
+            ptnAcc, scatterCount, mtRand, 1.0, interrupter);
         scatter(*interiorMaskPtr);
     }
 
     if (interrupter && interrupter->wasInterrupted()) return;
 
-    auto csp = ClosestSurfacePoint<GridT>::create(grid, isovalue, interrupter);
+    auto csp = ClosestSurfacePoint<GridT>::create(*gridPtr, isovalue, interrupter);
     if (!csp) return;
 
     // Add extra instance points in the interior narrow band.
@@ -740,13 +830,13 @@ fillWithSpheres(
 
     if (interrupter && interrupter->wasInterrupted()) return;
 
+    // Assign a radius to each candidate sphere.  The radius is the world-space
+    // distance from the sphere's center to the closest surface point.
     std::vector<float> instanceRadius;
     if (!csp->search(instancePoints, instanceRadius)) return;
 
-    std::vector<unsigned char> instanceMask(instancePoints.size(), 0);
     float largestRadius = 0.0;
     int largestRadiusIdx = 0;
-
     for (size_t n = 0, N = instancePoints.size(); n < N; ++n) {
         if (instanceRadius[n] > largestRadius) {
             largestRadius = instanceRadius[n];
@@ -754,8 +844,8 @@ fillWithSpheres(
         }
     }
 
-    Vec3s pos;
-    Vec4s sphere;
+    std::vector<unsigned char> instanceMask(instancePoints.size(), 0);
+
     minRadius = float(minRadius * transform.voxelSize()[0]);
     maxRadius = float(maxRadius * transform.voxelSize()[0]);
 
@@ -765,12 +855,13 @@ fillWithSpheres(
 
         largestRadius = std::min(maxRadius, largestRadius);
 
-        if (s != 0 && largestRadius < minRadius) break;
+        if ((int(s) >= minSphereCount) && (largestRadius < minRadius)) break;
 
-        sphere[0] = float(instancePoints[largestRadiusIdx].x());
-        sphere[1] = float(instancePoints[largestRadiusIdx].y());
-        sphere[2] = float(instancePoints[largestRadiusIdx].z());
-        sphere[3] = largestRadius;
+        const Vec4s sphere(
+            float(instancePoints[largestRadiusIdx].x()),
+            float(instancePoints[largestRadiusIdx].y()),
+            float(instancePoints[largestRadiusIdx].z()),
+            largestRadius);
 
         spheres.push_back(sphere);
         instanceMask[largestRadiusIdx] = 1;
@@ -817,7 +908,7 @@ ClosestSurfacePoint<GridT>::initialize(
         volume_to_mesh_internal::identifySurfaceIntersectingVoxels(mask, tree, ValueT(isovalue));
 
         mSignTreePt.reset(new Int16TreeT(0));
-        mIdxTreePt.reset(new Index32TreeT(boost::integer_traits<Index32>::const_max));
+        mIdxTreePt.reset(new Index32TreeT(std::numeric_limits<Index32>::max()));
 
 
         volume_to_mesh_internal::computeAuxiliaryData(
@@ -868,7 +959,8 @@ ClosestSurfacePoint<GridT>::initialize(
 
     using Index32RootNodeT = typename Index32TreeT::RootNodeType;
     using Index32NodeChainT = typename Index32RootNodeT::NodeChainType;
-    BOOST_STATIC_ASSERT(boost::mpl::size<Index32NodeChainT>::value > 1);
+    static_assert(boost::mpl::size<Index32NodeChainT>::value > 1,
+        "expected tree depth greater than one");
     using Index32InternalNodeT =
         typename boost::mpl::at<Index32NodeChainT, boost::mpl::int_<1> >::type;
 
@@ -964,6 +1056,6 @@ ClosestSurfacePoint<GridT>::searchAndReplace(std::vector<Vec3R>& points,
 
 #endif // OPENVDB_TOOLS_VOLUME_TO_MESH_HAS_BEEN_INCLUDED
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
