@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -50,6 +50,7 @@ public:
     void tearDown() override { openvdb::uninitialize(); }
 
     CPPUNIT_TEST_SUITE(TestIndexFilter);
+    CPPUNIT_TEST(testActiveFilter);
     CPPUNIT_TEST(testMultiGroupFilter);
     CPPUNIT_TEST(testRandomLeafFilter);
     CPPUNIT_TEST(testAttributeHashFilter);
@@ -58,6 +59,7 @@ public:
     CPPUNIT_TEST(testBinaryFilter);
     CPPUNIT_TEST_SUITE_END();
 
+    void testActiveFilter();
     void testMultiGroupFilter();
     void testRandomLeafFilter();
     void testAttributeHashFilter();
@@ -101,7 +103,25 @@ public:
     ThresholdFilter(const int threshold)
         : mThreshold(threshold) { }
 
+    bool isPositiveInteger() const { return mThreshold > 0; }
+    bool isMax() const { return mThreshold == std::numeric_limits<int>::max(); }
+
     static bool initialized() { return true; }
+    inline index::State state() const
+    {
+        if (LessThan) {
+            if (isMax())                    return index::ALL;
+            else if (!isPositiveInteger())  return index::NONE;
+        }
+        else {
+            if (isMax())                    return index::NONE;
+            else if (!isPositiveInteger())  return index::ALL;
+        }
+        return index::PARTIAL;
+    }
+
+    template <typename LeafT>
+    static index::State state(const LeafT&) { return index::PARTIAL; }
 
     template <typename LeafT>
     void reset(const LeafT&) { }
@@ -167,6 +187,123 @@ multiGroupMatches(  const LeafT& leaf, const Index32 size,
 }
 
 
+void
+TestIndexFilter::testActiveFilter()
+{
+    // create a point grid, three points are stored in two leafs
+
+    PointDataGrid::Ptr points;
+    std::vector<Vec3s> positions{{1, 1, 1}, {1, 2, 1}, {10.1f, 10, 1}};
+
+    const double voxelSize(1.0);
+    math::Transform::Ptr transform(math::Transform::createLinearTransform(voxelSize));
+
+    points = createPointDataGrid<NullCodec, PointDataGrid>(positions, *transform);
+
+    // check there are two leafs
+
+    CPPUNIT_ASSERT_EQUAL(Index32(2), points->tree().leafCount());
+
+    ActiveFilter activeFilter;
+    InactiveFilter inActiveFilter;
+
+    CPPUNIT_ASSERT_EQUAL(index::PARTIAL, activeFilter.state());
+    CPPUNIT_ASSERT_EQUAL(index::PARTIAL, inActiveFilter.state());
+
+    { // test default active / inactive values
+        auto leafIter = points->tree().cbeginLeaf();
+
+        CPPUNIT_ASSERT_EQUAL(index::PARTIAL, activeFilter.state(*leafIter));
+        CPPUNIT_ASSERT_EQUAL(index::PARTIAL, inActiveFilter.state(*leafIter));
+
+        auto indexIter = leafIter->beginIndexAll();
+        activeFilter.reset(*leafIter);
+        inActiveFilter.reset(*leafIter);
+
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!indexIter);
+        ++leafIter;
+
+        indexIter = leafIter->beginIndexAll();
+        activeFilter.reset(*leafIter);
+        inActiveFilter.reset(*leafIter);
+
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!indexIter);
+    }
+
+    auto firstLeaf = points->tree().beginLeaf();
+
+    { // set all voxels to be inactive in the first leaf
+        firstLeaf->getValueMask().set(false);
+
+        auto leafIter = points->tree().cbeginLeaf();
+
+        CPPUNIT_ASSERT_EQUAL(index::NONE, activeFilter.state(*leafIter));
+        CPPUNIT_ASSERT_EQUAL(index::ALL, inActiveFilter.state(*leafIter));
+
+        auto indexIter = leafIter->beginIndexAll();
+        activeFilter.reset(*leafIter);
+        inActiveFilter.reset(*leafIter);
+
+        CPPUNIT_ASSERT(!activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!indexIter);
+        ++leafIter;
+
+        indexIter = leafIter->beginIndexAll();
+        activeFilter.reset(*leafIter);
+        inActiveFilter.reset(*leafIter);
+
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!indexIter);
+    }
+
+    { // set all voxels to be active in the first leaf
+        firstLeaf->getValueMask().set(true);
+
+        auto leafIter = points->tree().cbeginLeaf();
+
+        CPPUNIT_ASSERT_EQUAL(index::ALL, activeFilter.state(*leafIter));
+        CPPUNIT_ASSERT_EQUAL(index::NONE, inActiveFilter.state(*leafIter));
+
+        auto indexIter = leafIter->beginIndexAll();
+        activeFilter.reset(*leafIter);
+        inActiveFilter.reset(*leafIter);
+
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!indexIter);
+        ++leafIter;
+
+        indexIter = leafIter->beginIndexAll();
+        activeFilter.reset(*leafIter);
+        inActiveFilter.reset(*leafIter);
+
+        CPPUNIT_ASSERT(activeFilter.valid(indexIter));
+        CPPUNIT_ASSERT(!inActiveFilter.valid(indexIter));
+        ++indexIter;
+        CPPUNIT_ASSERT(!indexIter);
+    }
+}
+
 void
 TestIndexFilter::testMultiGroupFilter()
 {
@@ -224,6 +361,16 @@ TestIndexFilter::testMultiGroupFilter()
         groupHandle.set(0, true);
     }
 
+    { // test state()
+        std::vector<Name> include;
+        std::vector<Name> exclude;
+        MultiGroupFilter filter(include, exclude, leaf->attributeSet());
+        CPPUNIT_ASSERT_EQUAL(filter.state(), index::ALL);
+        include.push_back("all");
+        MultiGroupFilter filter2(include, exclude, leaf->attributeSet());
+        CPPUNIT_ASSERT_EQUAL(filter2.state(), index::PARTIAL);
+    }
+
     // test multi group iteration
 
     { // all (implicit, no include or exclude)
@@ -368,6 +515,8 @@ TestIndexFilter::testRandomLeafFilter()
 
         RandFilter filter(tree, 0);
 
+        CPPUNIT_ASSERT(filter.state() == index::PARTIAL);
+
         filter.mLeafMap[Coord(0, 0, 0)] = std::make_pair(0, 10);
         filter.mLeafMap[Coord(0, 0, 8)] = std::make_pair(1, 1);
         filter.mLeafMap[Coord(0, 8, 0)] = std::make_pair(2, 50);
@@ -462,6 +611,7 @@ TestIndexFilter::testAttributeHashFilter()
 
     { // construction, copy construction
         HashFilter filter(index, 0.0f);
+        CPPUNIT_ASSERT(filter.state() == index::PARTIAL);
         CPPUNIT_ASSERT(!filter.initialized());
         HashFilter filter2 = filter;
         CPPUNIT_ASSERT(!filter2.initialized());
@@ -605,6 +755,7 @@ TestIndexFilter::testLevelSetFilter()
 
     { // construction, copy construction
         LSFilter filter(*sphere, points->transform(), -4.0f, 4.0f);
+        CPPUNIT_ASSERT(filter.state() == index::PARTIAL);
         CPPUNIT_ASSERT(!filter.initialized());
         LSFilter filter2 = filter;
         CPPUNIT_ASSERT(!filter2.initialized());
@@ -825,6 +976,9 @@ TestIndexFilter::testBBoxFilter()
 struct NeedsInitializeFilter
 {
     inline bool initialized() const { return mInitialized; }
+    static index::State state() { return index::PARTIAL; }
+    template <typename LeafT>
+    inline index::State state(const LeafT&) { return index::PARTIAL; }
     template <typename LeafT>
     void reset(const LeafT&) { mInitialized = true; }
 private:
@@ -835,12 +989,15 @@ private:
 void
 TestIndexFilter::testBinaryFilter()
 {
+    const int intMax = std::numeric_limits<int>::max();
+
     { // construction, copy construction
         using InitializeBinaryFilter = BinaryFilter<NeedsInitializeFilter, NeedsInitializeFilter, /*And=*/true>;
 
         NeedsInitializeFilter needs1;
         NeedsInitializeFilter needs2;
         InitializeBinaryFilter filter(needs1, needs2);
+        CPPUNIT_ASSERT(filter.state() == index::PARTIAL);
         CPPUNIT_ASSERT(!filter.initialized());
         InitializeBinaryFilter filter2 = filter;
         CPPUNIT_ASSERT(!filter2.initialized());
@@ -855,6 +1012,11 @@ TestIndexFilter::testBinaryFilter()
     using GreaterThanFilter = ThresholdFilter<false>;
 
     { // less than
+        LessThanFilter zeroFilter(0); // all invalid
+        CPPUNIT_ASSERT(zeroFilter.state() == index::NONE);
+        LessThanFilter maxFilter(intMax); // all valid
+        CPPUNIT_ASSERT(maxFilter.state() == index::ALL);
+
         LessThanFilter filter(5);
         filter.reset(OriginLeaf(Coord(0, 0, 0)));
         std::vector<int> values;
@@ -871,6 +1033,11 @@ TestIndexFilter::testBinaryFilter()
     }
 
     { // greater than
+        GreaterThanFilter zeroFilter(0); // all valid
+        CPPUNIT_ASSERT(zeroFilter.state() == index::ALL);
+        GreaterThanFilter maxFilter(intMax); // all invalid
+        CPPUNIT_ASSERT(maxFilter.state() == index::NONE);
+
         GreaterThanFilter filter(94);
         filter.reset(OriginLeaf(Coord(0, 0, 0)));
         std::vector<int> values;
@@ -890,7 +1057,13 @@ TestIndexFilter::testBinaryFilter()
     { // binary and
         using RangeFilter = BinaryFilter<LessThanFilter, GreaterThanFilter, /*And=*/true>;
 
+        RangeFilter zeroFilter(LessThanFilter(0), GreaterThanFilter(10)); // all invalid
+        CPPUNIT_ASSERT(zeroFilter.state() == index::NONE);
+        RangeFilter maxFilter(LessThanFilter(intMax), GreaterThanFilter(0)); // all valid
+        CPPUNIT_ASSERT(maxFilter.state() == index::ALL);
+
         RangeFilter filter(LessThanFilter(55), GreaterThanFilter(45));
+        CPPUNIT_ASSERT(filter.state() == index::PARTIAL);
 
         filter.reset(OriginLeaf(Coord(0, 0, 0)));
 
@@ -911,6 +1084,11 @@ TestIndexFilter::testBinaryFilter()
     { // binary or
         using HeadTailFilter = BinaryFilter<LessThanFilter, GreaterThanFilter, /*And=*/false>;
 
+        HeadTailFilter zeroFilter(LessThanFilter(0), GreaterThanFilter(10)); // some valid
+        CPPUNIT_ASSERT(zeroFilter.state() == index::PARTIAL);
+        HeadTailFilter maxFilter(LessThanFilter(intMax), GreaterThanFilter(0)); // all valid
+        CPPUNIT_ASSERT(maxFilter.state() == index::ALL);
+
         HeadTailFilter filter(LessThanFilter(5), GreaterThanFilter(95));
         filter.reset(OriginLeaf(Coord(0, 0, 0)));
 
@@ -932,6 +1110,6 @@ TestIndexFilter::testBinaryFilter()
     }
 }
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
