@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2016 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -598,8 +598,16 @@ TestTreeIterators::testDepthBounds()
             ASSERT_DOUBLES_EXACTLY_EQUAL(sphereTree.getValue(ijk), *iter);
         }
     }
+    {
+        // FX-10221 regression test
+        // This code generated an infinite loop in OpenVDB 5.1.0 and earlier:
+        openvdb::FloatTree emptyTree;
+        auto iter = emptyTree.cbeginValueAll();
+        iter.setMinDepth(2);
+        CPPUNIT_ASSERT(!iter);
+    }
 }
 
-// Copyright (c) 2012-2016 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
