@@ -1,6 +1,6 @@
 ///////////////////////////////////////////////////////////////////////////
 //
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 //
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
@@ -37,7 +37,9 @@
 #include <openvdb/tools/Prune.h>
 #include <openvdb/tree/LeafManager.h>
 #include <openvdb/util/logging.h>
+#include <algorithm> // for std::min()
 #include <cmath> // for std::abs(), std::fabs(), std::floor()
+#include <limits>
 #include <type_traits> // for std::is_const
 
 
@@ -1422,7 +1424,7 @@ public:
 
         // obtain cumulative point offsets and total points
         std::vector<openvdb::Index64> pointOffsets;
-        const openvdb::Index64 total = openvdb::points::getPointOffsets(pointOffsets, tree);
+        const openvdb::Index64 total = openvdb::points::pointOffsets(pointOffsets, tree);
 
         // @todo use glDrawArrays with GL_POINTS to avoid generating indices
         GLfloatVec values(total * 3);
@@ -1689,6 +1691,6 @@ MeshModule::render()
 
 } // namespace openvdb_viewer
 
-// Copyright (c) 2012-2017 DreamWorks Animation LLC
+// Copyright (c) 2012-2018 DreamWorks Animation LLC
 // All rights reserved. This software is distributed under the
 // Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
